# README #

bristoSOFT Contacts is a group oriented contacts management system featuring a Qt GUI, python control and PostgreSQL backend database.  It runs on Linux, Windows and MacIntosh among others.  

To install just pip install bristosoftcontacts.  To run bristoSOFT contacts run main.py.  The file main.py is the entry point. 

 

### What is this repository for? ###

* Quick summary
* Version
* [Learn Markdown](https://bitbucket.org/tutorials/markdowndemo)

### How do I get set up? ###

* Summary of set up
* Configuration
* Dependencies
* Database configuration
* How to run tests
* Deployment instructions

### Contribution guidelines ###

* Writing tests
* Code review
* Other guidelines

### Who do I talk to? ###

* Repo owner or admin
* Other community or team contact
